@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Apache2::Const;
 
-sub handler {
+sub handler :method {
     my ($class_or_obj, $req) = @_;
 
     $req->content_type('text/plain');
